/*
  Copyright Red Hat, Inc. 2005

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to the
  Free Software Foundation, Inc.,  675 Mass Ave, Cambridge,
  MA 02139, USA.
*/
/*
 * Author: Stanko Kupcevic <kupcevic@redhat.com>
 */


#ifndef SSLClient_h
#define SSLClient_h

#include "Socket.h"

#include "String.h"
#include <openssl/ssl.h>


#define _privkey          "/var/lib/luci/var/certs/privkey.pem"
#define _pubkey           "/var/lib/luci/var/certs/cacert.pem"
#define _trust_CAs        "/var/lib/luci/var/certs/trust_CAs"
#define _certs_store_dir  "/var/lib/luci/var/certs/peers"


// NOT THREAD SAFE


class SSLClient
{
 public:
  SSLClient(ClientSocket sock);
  virtual ~SSLClient();

  bool connect(unsigned int timeout);

  String send(const String& msg, unsigned int timeout);
  String recv(unsigned int timeout, size_t& buflen);


  bool peer_has_cert();
  bool peer_cert_trusted();  // return true if peer's cert is trusted (either thru CA chain, or saved in cert_store)

  String peer_cert_fingerprint(String& digest);

  bool trust_peer_cert(const String&);
  bool untrust_peer_cert();  // remove peer's cert from cert_store

  ClientSocket& socket();

 private:
  SSLClient(const SSLClient&);
  SSLClient operator=(const SSLClient&);

  ClientSocket _sock;
  SSL*         _ssl;
  String  _cert_pem;

  bool _connected;

  void check_error(int value, bool& want_read, bool& want_write);


};  // class SSLClient


#endif  // SSLClient_h
