#! /usr/bin/env python

# Copyright Red Hat, Inc. 2006
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License as published by the
#  Free Software Foundation; either version 2, or (at your option) any
#  later version.
#
#  This program is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; see the file COPYING.  If not, write to the
#  Free Software Foundation, Inc.,  675 Mass Ave, Cambridge, 
#  MA 02139, USA.

'''
Script name:    GA_0170_Online_Documentation_Portlet.py
Creation date:  Dec 2006
Purpose:        Prototype automated GUI test for RHEL5 Conga (luci server web app) - automated
                with Selenium RC (remote control) 0.9.0
Summary:        Test for Conga use case CGA-0170 - verify the online user documentation
                Regression test for: https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=212991
'''

__author__ = 'Len DiMaggio <ldimaggi@redhat.com>'

from selenium import selenium
import unittest, time, re
from conga_Helpers import *
import time
import logging
from loggerObject import loggerObject

class CGA_0170_Online_Documentation_Portlet (unittest.TestCase):

    def setUp(self):      
               
        # Set up logging      
        self.theloggerObject = setupLogger (CONGA_DEBUG_LOG)
        self.logger = self.theloggerObject.getLogger()
        self.logger.info('-----------------------------------------------------------') 
  
        """Establish connection to selenium server, login to luci """
        self.verificationErrors = []
        self.selenium = login (CONGA_ADMIN_USERNAME, CONGA_ADMIN_PASSWORD)

        """Test to create and delete storage systems"""
        sel = self.selenium

    def test_docs(self):
        """Test to verify on-line Help docs"""
        self.logger.info('Starting test case CGA_0170_Online_Documentation_Portlet.test_docs')
        
        sel = self.selenium
        
        # Access the on-line help
        sel.click("link=help")
        sel.wait_for_pop_up("Conga Help", "30000")        
        sel.select_window('Conga Help')
        
        # Grab all the text       
        theText = sel.get_html_source()

        # Validation - check the offsets for the items in the HELP list             
        for theItem in HELP_LIST:
            self.logger.debug('Verify offset of help text "' + theItem + '" = ' + str(theText.index(theItem)))
            self.assertEqual (theText.index(theItem), HELP_DICTIONARY[theItem])
            
        # Select the main window    
        sel.select_window('null')
        
        self.logger.info('Ending test case CGA_0170_Online_Documentation_Portlet.test_docs')
  
    def tearDown(self):  
        """Logout and stop Selenium session"""
        logout(self.selenium)
        self.assertEqual([], self.verificationErrors)
        closeLogger (self.theloggerObject)

def suite():
        suite = unittest.TestSuite()
        suite.addTest(CGA_0170_Online_Documentation_Portlet('test_docs'))
        return suite

if __name__ == "__main__":
    #unittest.main()
    unittest.TextTestRunner( verbosity=2 ).run( suite() )
