#! /usr/bin/env python

# Copyright Red Hat, Inc. 2006
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License as published by the
#  Free Software Foundation; either version 2, or (at your option) any
#  later version.
#
#  This program is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; see the file COPYING.  If not, write to the
#  Free Software Foundation, Inc.,  675 Mass Ave, Cambridge, 
#  MA 02139, USA.

'''
Script name:    CGA_0200_Create_cluster.py
Creation date:  Dec 2006
Purpose:        Prototype automated GUI test for RHEL5 Conga (luci server web app) - automated
                with Selenium RC (remote control) 0.9.0 (http://www.openqa.org/selenium/)
Summary:        Simple, demo/prototype test for Conga
'''

__author__ = 'Len DiMaggio <ldimaggi@redhat.com>'

from conga_Helpers import *
from selenium import selenium
import unittest, time, re

class CGA_0200_Create_cluster(unittest.TestCase):

    def setUp(self):
        # Set up logging      
        self.theloggerObject = setupLogger (CONGA_DEBUG_LOG)
        self.logger = self.theloggerObject.getLogger()
        self.logger.info('-----------------------------------------------------------') 
        
        """Establish connection to selenium server, login to luci """
        self.verificationErrors = []
        self.selenium = login (CONGA_ADMIN_USERNAME, CONGA_ADMIN_PASSWORD)
 
    def test_congaCluster(self):
        """Test to create and delete a cluster"""

        self.logger.info('Starting test case CGA_0200_Create_cluster.test_congaCluster')

        # TODO - Need to generalize this function - but as of 20061129, note tng3-1 
        # is not responding to the creation of a cluster
        sel = self.selenium
        sel.open("/luci/homebase")
        sel.click("link=cluster")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
        sel.click("link=Create a New Cluster")

        # Create the new "testCluster" cluster
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
        sel.type("clustername", "testCluster")
        self.logger.debug('Create cluster: testCluster')

        # Add the nodes to the cluster
        # Needed to generalize statements like this:
        #     sel.type("__SYSTEM1:Addr", "tng3-2.lab.msp.redhat.com")
        #     sel.type("__SYSTEM1:Passwd", "password")
        #     sel.click("//input[@value='Add Another Row']")
        systemCounter = 0
        for systemName in CONGA_SMALL_CLUSTER_SYSTEMS.keys():
            sel.type("__SYSTEM" + str(systemCounter) + ":Addr", systemName)
            sel.type("__SYSTEM" + str(systemCounter) + ":Passwd", CONGA_SMALL_CLUSTER_SYSTEMS[systemName])
            systemCounter = systemCounter + 1
            if (systemCounter > 2):
                sel.click("//input[@value='Add a cluster node']")          
        #sel.click("document.adminform.rhn_dl[1]")
        sel.click("Submit")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)

        self.assertEqual('Add the cluster "testCluster" to the Luci management interface?' , sel.get_confirmation())
        #sel.click("link=testCluster")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)

        # Wait 5 minutes for the cluster nodes to be rebooted
        time.sleep (300)

        # Validation - verify that the newly created cluster shows up in the cluster list        
        sel.click("link=homebase")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
        sel.click("link=Manage Systems")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
        self.assertTrue (sel.is_text_present('testCluster'))
        self.assertTrue (sel.is_element_present("name=__CLUSTER:X___testCluster"))
        
        # Then - delete the cluster
        sel.click("link=homebase")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
        sel.click("link=cluster")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
        sel.select("cluster_action", "label=Delete this cluster")
        sel.click("//input[@value='Go']")
    
        self.assertEqual("Delete this cluster?", sel.get_confirmation())
        time.sleep (60)

        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
        sel.click("link=homebase")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
        sel.click("link=Manage Systems")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)       

        # Delete the storage systems created when the cluster was created
        for systemName in CONGA_SMALL_CLUSTER_SYSTEMS:
            deleteStorageSystem(sel, systemName, self.logger)
           # Validation - verify that the success message was displayed for each storage system
            self.assertEqual("Do you really want to remove the following managed systems:\nStorage Systems:\n-" + systemName, sel.get_confirmation())
            sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
            self.assertTrue (sel.is_text_present('Removed storage system "' + systemName + '" successfully'))

        self.logger.info('Ending test case CGA_0200_Create_cluster.test_congaCluster')

    def tearDown(self):
        """Logout and stop Selenium session"""
        logout(self.selenium)
        self.assertEqual([], self.verificationErrors)
        closeLogger (self.theloggerObject)

def suite():
        suite = unittest.TestSuite()
        suite.addTest(CGA_0200_Create_cluster('test_congaCluster'))
        return suite

if __name__ == "__main__":
    #unittest.main()
    unittest.TextTestRunner(verbosity=2).run(suite())
