#! /usr/bin/env python

# Copyright Red Hat, Inc. 2006
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License as published by the
#  Free Software Foundation; either version 2, or (at your option) any
#  later version.
#
#  This program is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; see the file COPYING.  If not, write to the
#  Free Software Foundation, Inc.,  675 Mass Ave, Cambridge, 
#  MA 02139, USA.

'''
Script name:    congaDemoTests.py
Creation date:  Dec 2006
Purpose:        Prototype automated GUI test for RHEL5 Conga (luci server web app) - automated
                with Selenium RC (remote control) 0.9.0 (http://www.openqa.org/selenium/)
Summary:        Simple, demo/prototype test for Conga
'''

__author__ = 'Len DiMaggio <ldimaggi@redhat.com>'

from conga_Helpers import *
from selenium import selenium
import unittest, time, re
import logging
from loggerObject import loggerObject
from cleaner import *

class congaDemoTests(unittest.TestCase):

    def setUp(self):
        
        #temp = cleaner()    
        #temp.cleanup()
        
        # Set up logging      
        self.theloggerObject = setupLogger (CONGA_DEBUG_LOG)
        self.logger = self.theloggerObject.getLogger()
        self.logger.info('-----------------------------------------------------------') 
        
        """Establish connection to selenium server, login to luci """
        self.verificationErrors = []
        self.selenium = login (CONGA_ADMIN_USERNAME, CONGA_ADMIN_PASSWORD)     
 
    def test_congaStorage(self):
        """Test to create and delete storage systems"""
        self.logger.info('Starting test case congaDemoTests.test_congaStorage')    
        sel = self.selenium

        # Create the storage systems
        for systemName in CONGA_STORAGE_SYSTEMS:
            createStorageSystem(sel, systemName, CONGA_STORAGE_SYSTEMS[systemName], self.logger)
            # Validation - verify that the success message was displayed for each storage system
            self.assertEqual("Do you really want to add the following Storage Systems:\n" + systemName, sel.get_confirmation())
            sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
            self.assertTrue (sel.is_text_present('Added storage system "' + systemName + '" successfully'))            
            
        # View the defined storage systems 
        sel.select_window("null")
        sel.click("link=Manage Systems")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)

        # Delete the storage systems
        for systemName in CONGA_STORAGE_SYSTEMS:
            deleteStorageSystem(sel, systemName, self.logger)
           # Validation - verify that the success message was displayed for each storage system
            self.assertEqual("Do you really want to remove the following managed systems:\nStorage Systems:\n-" + systemName, sel.get_confirmation())
            sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
            self.assertTrue (sel.is_text_present('Removed storage system "' + systemName + '" successfully'))

        self.logger.info('Ending test case congaDemoTests.test_congaStorage')
        
    def test_congaUsers(self):
        """Test to create and delete conga users"""
        self.logger.info('Starting test case congaDemoTests.test_congaUsers')        
        sel = self.selenium

        # Create the users
        for userName in CONGA_USERS.keys(): 
            createUser (sel, userName, CONGA_USERS[userName], self.logger)
            # Validation - verify that the success message was displayed for each user
            self.assertEqual('Do you really want to add the user "' + userName + '"?', sel.get_confirmation())
            sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
            self.assertTrue (sel.is_text_present('Added new user "' + userName + '" successfully')) 

        # Return to homebase page
        sel.click("link=homebase")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)     

        # Delete the users 
        for userName in CONGA_USERS.keys(): 
            deleteUser (sel, userName, self.logger)
            # Validation - verify that the success message was displayed for each user
            self.assertEqual('Do you really want to remove the user "' + userName + '"?', sel.get_confirmation())
            sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
            self.assertTrue (sel.is_text_present('User "' + userName + '" has been deleted'))  

        self.logger.info('Ending test case congaDemoTests.test_congaUsers')

    def tearDown(self):
        """Logout and stop Selenium session"""
        logout(self.selenium)
        self.assertEqual([], self.verificationErrors)
        closeLogger (self.theloggerObject)

def suite():
        suite = unittest.TestSuite()
        suite.addTest(congaDemoTests('test_congaStorage'))
        suite.addTest(congaDemoTests('test_congaUsers'))
        return suite

if __name__ == "__main__":
    #unittest.main()
    unittest.TextTestRunner(verbosity=2).run(suite())
    
# To write pyunit-generated output to file
#    tests = unittest.defaultTestLoader.loadTestsFromTestCase(congaDemoTests) 
#    output = open("/var/tmp/output-file.txt", "w") 
#    unittest.TextTestRunner(output).run(tests) 
#    output.close() 
