#! /usr/bin/env python

#  Copyright (C) Red Hat, Inc. 2006-2008
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License as published by the
#  Free Software Foundation; either version 2, or (at your option) any
#  later version.
#
#  This program is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; see the file COPYING.  If not, write to the
#  Free Software Foundation, Inc.,  675 Mass Ave, Cambridge, 
#  MA 02139, USA.

'''
Script name:    conga_Helpers.py
Creation date:  Dec 2006
Purpose:        Prototype automated GUI test for RHEL5 Conga (luci server web app) - automated
                with Selenium RC (remote control) 0.9.0 (http://www.openqa.org/selenium/)
Summary:        Common routines, global variables
'''

__author__ = 'Len DiMaggio <ldimaggi@redhat.com>'

from selenium import selenium
import unittest, time, re
import logging
import logging.handlers
from loggerObject import loggerObject

# Define data to support tests - global for now

CONGA_ADMIN_USERNAME = 'admin'
CONGA_ADMIN_PASSWORD = 'foobar'
CONGA_SERVER = 'http://dell-pe1650-2.test.redhat.com:8080'
PAGE_DISPLAY_DELAY = '60000'
CONGA_LOG = '/var/tmp/congaTest.log'
CONGA_DEBUG_LOG = '/var/tmp/congaTest_debug.log'

# 20061130 - Node tng3-1 isn't booting, node tng3-4 is having some problems too

CONGA_STORAGE_SYSTEMS = { #'tng3-1.lab.msp.redhat.com':'password', 
                         #'tng3-2.lab.msp.redhat.com':'password',
                         'dell-pe1950-1.test.redhat.com':'foobar',
                         'pogolinux-1.test.redhat.com':'foobar',
#                         'pogolinux-2.test.redhat.com':'foobar'
}

CONGA_SMALL_CLUSTER_SYSTEMS = {  #'tng3-1.lab.msp.redhat.com':'password', 
#                         #'tng3-2.lab.msp.redhat.com':'password', 
                         'dell-pe1950-1.test.redhat.com':'foobar',
                         'pogolinux-1.test.redhat.com':'foobar',
#                         'pogolinux-2.test.redhat.com':'foobar'
}

CONGA_LARGE_CLUSTER_SYSTEMS = {#'tng3-1.lab.msp.redhat.com':'password', 
                         #'tng3-2.lab.msp.redhat.com':'password', 
                         'dell-pe1950-1.test.redhat.com':'foobar',
                         'pogolinux-1.test.redhat.com':'foobar',
#                         'pogolinux-2.test.redhat.com':'foobar'
}

CONGA_USERS =           {#'user1':'user1_password', 
                         #'user2':'user2_password', 
                         'user3':'user3_password', 
                         'user4':'user4_password', 
                         'user5':'user5_password', 
                         'user6':'user6_password', 
                         'user7':'user7_password', 
                         'user8':'user8_password', 
                         'user9':'user9_password', 
                         'user10':'user10_password'}

CONGA_USERS_SYSTEMS =   {#'user1':'tng3-1.lab.msp.redhat.com', 
                         #'user2':'tng3-2.lab.msp.redhat.com', 
                         'user3':'dell-pe1950-1.test.redhat.com', 
                         'user4':'pogolinux-1.test.redhat.com', 
                         'user5':'pogolinux-2.test.redhat.com'
                         }
   
# Data used to verify the on-line help contents. The Dictionary contains
# strings and offsets of the strings in the help as of 20061207   
HELP_LIST = ['Conga User Manual',
             'Introduction', 
             'Conga Architecture', 
             'Homebase Tab', 
             'Cluster Tab', 
             'Storage Tab']
        
HELP_DICTIONARY = {'Conga User Manual':81,
                   'Introduction':204,
                   'Conga Architecture':229,
                   'Homebase Tab':4261,
                   'Cluster Tab':12284,
                   'Storage Tab':23837 }

def createStorageSystem(sel, systemName, systemPassword, theLogger):
    """Common code to create storage systems"""
    theLogger.debug ('Create storage system: ' + systemName)
    sel.click("link=Add a System")
    sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
    sel.type("__SYSTEM0:Addr", systemName)        
    sel.type("__SYSTEM0:Passwd", systemPassword)
    sel.click("Submit")
    sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)

def deleteStorageSystem(sel, systemName, theLogger):
    """Common code to delete storage systems"""
    try:
        theLogger.debug('Delete storage system: ' + systemName)
        # Need to handle artifacts names - underscores in strings, not periods
        systemNameMod = systemName.replace('.', '_')
        
        # Added 20070418 - ldimaggi - to keep up with changes to GUI
        systemNameMod = "X___" + systemNameMod
        
        sel.click("name=__SYSTEM:" + systemNameMod)
        sel.click("document.adminform.Submit")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)          
    except:
        print 'Unable to delete system: ' + systemName

def createUser(sel, userName, userPassword, theLogger):
    """Common code to create users"""
    theLogger.debug('Create user: ' + userName)
    sel.click("link=Add a User")
    sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
    sel.type("newUserName", userName)
    sel.type("newPassword", userPassword)     
    sel.type("newPasswordConfirm", userPassword)
    sel.click("Submit")
    sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
    
def deleteUser(sel, userName, theLogger):
    """Common code to delete users"""
    try:
        theLogger.debug('Delete user: ' + userName)
        sel.click("link=Delete a User")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
        sel.select("deluserId", "label=" + userName)
        sel.click("Submit")
        sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)    
    except:
        print 'Unable to delete user: ' + userName
        
def login(userName, password):
    """Establish connection to selenium server, login to luci """
    sel = selenium("localhost", 4444, "*firefox", CONGA_SERVER)
    sel.start()

    #  Login to the luci web app
    sel.open(CONGA_SERVER)

    # Wait for "Redirecting, please wait to complete" - it seems like this should not be needed,
    # but as of 20061130, it still is
    time.sleep(10)
    sel.type("__ac_name", userName)
    sel.type("__ac_password", password)
    sel.click("submit")
    sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
    return sel

def logout(sel):
    """Logout and stop Selenium session"""
    sel.click("link=Log out")
    sel.wait_for_page_to_load(PAGE_DISPLAY_DELAY)
    sel.stop()
    
def setupLogger (testName):   
    """Create logger - use this message format:  2003-07-08 16:49:45,896 ERROR We have a problem
    For now - 20061213 - just append all log messages to a single log file """
    logger = logging.getLogger('congaTestLogger')
    
    # Why use a RotatingFileHandler? To keep track of previous test results - maybe?
    #hdlr = logging.handlers.RotatingFileHandler(testName, 'a', 1024000, 10)
    hdlr = logging.FileHandler(testName, 'a')
    
    formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
    hdlr.setFormatter(formatter)
    logger.addHandler(hdlr) 
    #logger.setLevel(logging.WARNING)
    logger.setLevel(logging.DEBUG)
    
    theloggerObject = loggerObject()
    theloggerObject.setLogger(logger)
    theloggerObject.setHandler(hdlr)
    return theloggerObject
    
def closeLogger (theloggerObject):
    """Close the logger - roll the logs"""
    theLogger = theloggerObject.getLogger()
    theHandler = theloggerObject.getHandler()
    theLogger.removeHandler(theHandler)
    theHandler.close()
#    theHandler.doRollover()
    
